==> qtjambi-scxml-debuginfo-windows-x64-5.15.17.jar: sources/QtJambiScxml/QScxmlInvokableService_shell.h <==
#ifndef QSCXMLINVOKABLESERVICE_SHELL_H
#define QSCXMLINVOKABLESERVICE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtScxml/qscxmlinvokableservice.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtScxml/qscxmlevent.h>
#include <QtScxml/qscxmlstatemachine.h>
#include <QtJambi/RegistryAPI>


class QScxmlInvokableService_shell : public QScxmlInvokableService, public QtJambiShellInterface
{
public:
    QScxmlInvokableService_shell(QScxmlStateMachine* parentStateMachine0, QScxmlInvokableServiceFactory* parent1);
    ~QScxmlInvokableService_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QString id() const override;
    QString name() const override;
    void postEvent(QScxmlEvent* event0) override;
    bool start() override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QScxmlInvokableService_access : public QScxmlInvokableService
{
    jstring __qt_id(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jstring __qt_name(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_postEvent_QScxmlEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject event0);
    jboolean __qt_start(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QSCXMLINVOKABLESERVICE_SHELL_H

==> qtjambi-scxml-debuginfo-windows-x64-6.5.3.jar: sources/QtJambiScxml/QScxmlInvokableService_shell.h <==
#ifndef QSCXMLINVOKABLESERVICE_SHELL_H
#define QSCXMLINVOKABLESERVICE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtScxml/qscxmlinvokableservice.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtScxml/qscxmlevent.h>
#include <QtScxml/qscxmlstatemachine.h>
#include <QtJambi/RegistryAPI>


class QScxmlInvokableService_shell : public QScxmlInvokableService, public QtJambiShellInterface
{
public:
    QScxmlInvokableService_shell(QScxmlStateMachine* parentStateMachine0, QScxmlInvokableServiceFactory* parent1);
    ~QScxmlInvokableService_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QString id() const override;
    QString name() const override;
    void postEvent(QScxmlEvent* event0) override;
    bool start() override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QScxmlInvokableService_access : public QScxmlInvokableService
{
    jstring __qt_id(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jstring __qt_name(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_postEvent_QScxmlEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject event0);
    jboolean __qt_start(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QSCXMLINVOKABLESERVICE_SHELL_H
